#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 url
version:              2.1.3
visibility:           public
id:                   url-2.1.3-7Kl4E3eXP9D927NfHGnLmQ
key:                  url-2.1.3-7Kl4E3eXP9D927NfHGnLmQ
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Iavor S. Diatchki
homepage:             http://www.haskell.org/haskellwiki/Url
synopsis:             A library for working with URLs.
description:          A library for working with URLs.
category:             Web
abi:                  72f396ab953b143ee3961b8e45b85c0a
exposed:              True
exposed-modules:      Network.URL
import-dirs:          /usr/lib/ghc-9.6.6/site-local/url-2.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/url-2.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/url-2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-url
hs-libraries:         HSurl-2.1.3-7Kl4E3eXP9D927NfHGnLmQ
depends:
    base-4.18.2.1 utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1

haddock-interfaces:   /usr/share/doc/haskell-url/html/url.haddock
haddock-html:         /usr/share/doc/haskell-url/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

